pub struct Face {
pub boundary: Option<HalfEdgeId>,
}Expand description
A region of the plane bounded by a cycle of half-edges.
Fields
boundary: Option<HalfEdgeId>Any half-edge on this face’s outer boundary.
None only for the unbounded face of an arrangement with no edges.